#vider la mmoire
rm(list=ls())

#librairie lecture fichier excel
library(xlsx)

#changement de rpertoire
setwd("D:/DataMining/Databases_for_mining/dataset_for_soft_dev_and_comparison/fact_analysis/dynGraph")

#chargement des donnes dans la premire feuille de calcul
#les donnes sont dans la premire feuille
autos.data <- read.xlsx(file="autos_acp_factominer_dyngraph.xls",header=T,sheetIndex=1)

#premire colonne = label (etiquette) des observations
rownames(autos.data) <- autos.data[,1]
autos.data <- autos.data[,-1]

#qqs vrifications
#affichage
print(autos.data)

#statistiques descriptives
summary(autos.data)

#nuages de points
pairs(autos.data)

#charger les bibliothques FactoMineR et dynGraph
library(FactoMineR)
library(dynGraph)

#*******************************
# ACP avec PCA de FactoMineR
#*******************************

#centrage et rduction des donnes --> scale.unit = T
#quanti.sup -> numro des colonnes des var. quanti. supp.
#quali.sup -> numro des colonnes des var. quali. supp.
#pas de graphiques pour l'instant -> graph = F
autos.acp <- PCA(autos.data,scale.unit = T,quanti.sup=8:9,quali.sup=7,graph=F)

#obtenir les proprits de l'objet  autos.acp
print(autos.acp)

#*************************
#**** val. propres *******
#*************************

#obtenir les variances associes aux axes c.--d. les valeurs propres
val.propres <- autos.acp$eig[,1]
print(val.propres)

#scree plot (graphique des boulis des valeurs propres)
plot(1:6,val.propres,type="b",ylab="Valeurs propres",xlab="Composante",main="Scree plot")

#intervalle de confiance des val.propres  95% (Saporta, page 172)
n <- nrow(autos.data)
val.basse <- val.propres * exp(-1.96 * sqrt(2.0/(n-1)))
val.haute <- val.propres * exp(+1.96 * sqrt(2.0/(n-1)))

#tableau
tableau <- cbind(val.basse,val.propres,val.haute)
colnames(tableau) <- c("B.Inf.","Val.","B.Sup")
print(tableau,digits=3)

#*************************************************
#coordonnes des variables sur les axes factoriels
#*************************************************

#**** corrlation variables-facteurs ****
print(autos.acp$var$cor[,1:2],digits=2)

#carrs de la corrlation = cos2
print(autos.acp$var$cos2[,1:2],digits=2)

#cumul carrs de la corrlation
print(t(apply(autos.acp$var$cos2[,1:2],1,cumsum)),digits=2)

#*** cercle des corrlations - variables actives ***
plot(autos.acp,choix="var",title="Cercle des corrlations",invisible="quanti.sup")

#***************************************************************
#*** projection des individus dans le premier plan factoriel ***
#***************************************************************

# invisible = "quali" -> ne pas afficher les variables quali supplmentaires
plot(autos.acp,choix="ind",title="Individus - 1er plan",invisible="quali")

#****************************************************************************
#*** Caractrisation automatique des axes - Husson, Le, Pages, pages 23  25
#****************************************************************************
dimdesc(autos.acp, axes = 1:2, proba = 0.05)

#**************************************
#*** cosinus carr des individus actifs
#**************************************

#directement fournis par l'objet PCA
#ici pour les 2 premiers axes
autos.acp$ind$cos2[,1:2]

#**************************************
#*** contributions des individus actifs
#**************************************

#directement fournis par l'objet PCA
#ici pour les 2 premiers axes
autos.acp$ind$contrib[,1:2]

#***************************************
# traitement des variables illustratives
#***************************************

#*** cercle des corrlations - variables actives ET illustratives ***
plot(autos.acp,choix="var",title="Cercle des corrlations")

#corrlation et cosinus carr avec les deux premiers axes
print(cbind(autos.acp$quanti.sup$cor[,1:2],autos.acp$quanti.sup$cos2[,1:2]))

#*******************************************************************************
#positionner les modalits de la variable illustrative + calcul des valeurs test
#*******************************************************************************

#position dans le plan factoriel - barycentre pour chaque moda. de la var.quali
plot(autos.acp,choix="ind",title="Individus - 1er plan")   
#coloriage diffrent des individus pour chaque moda. de la var.quali n7
plot(autos.acp,choix="ind",title="Individus - 1er plan",habillage=7)

#moyennes conditionnelles et valeur test
carac.quali <- cbind(autos.acp$quali.sup$coord[,1:2],autos.acp$quali.sup$v.test[,1:2])
print(carac.quali)

#ellipse de confiance des modalits dans le plan factoriel
#crer un nouveau data.frame pour calculer les ellipse
new.autos <- cbind(as.data.frame(autos.data$FINITION),as.data.frame(autos.acp$ind$coord[,1:2]))
#calculer les ellipse de dispsersion autour des barycentres dans le plan
finition.ellipse <- coord.ellipse(new.autos,bary=T)
#reprsentation graphique
plot(autos.acp,ellipse=finition.ellipse,habillage=7)

#************************************************
# exploration graphique interactive avec dynGraph
#************************************************

#lancer l'outil d'exploration interactive
dynGraph(autos.acp)


